@@ -28,41 +28,45 @@ extern double transparency;
 UkmediaMiniMasterVolumeWidget::UkmediaMiniMasterVolumeWidget(QWidget *parent) : QWidget(parent)
 {
     masterWidget = new QFrame(this);
+    displayWidget = new QFrame(this);
     muteBtn = new UkuiButtonDrawSvg(masterWidget);
     displayVolumeLabel = new QLabel(masterWidget);
     masterVolumeSlider = new UkmediaVolumeSlider(masterWidget);
-//    masterWidget->setFrameShape(QFrame::Shape::Box);
-
+    this->setProperty("useSystemStyleBlur",true);
+    this->setWindowTitle("whole window blur");
+    this->setAttribute(Qt::WA_TranslucentBackground);
     deviceCombox = new QComboBox(this);
     switchBtn = new UkuiMediaButton(this);
     switchBtn->setParent(this);
-    switchBtn->setStyle(new CustomStyle());
+    switchBtn->setFlat(true);
+    switchBtn->setCheckable(false);
+    deviceBtn = new QPushButton(displayWidget);
+    deviceLabel = new QLabel(displayWidget);
+
+//    deviceLabel->setText(tr("Speaker (Realtek Audio)"));
+    displayWidget->setFixedSize(260,40);
+    QHBoxLayout *hLayout = new QHBoxLayout();
+    hLayout->addWidget(deviceBtn);
+    hLayout->addWidget(deviceLabel);
+    hLayout->setSpacing(4);
+    displayWidget->setLayout(hLayout);
+    hLayout->setContentsMargins(16,16,0,0);
 
-    deviceBtn = new QPushButton(this);
-    deviceLabel = new QLabel(tr("Speaker (Realtek Audio)"),this);
     QSpacerItem *item1 = new QSpacerItem(16,20);
     QSpacerItem *item2 = new QSpacerItem(13,20);
     QSpacerItem *item3 = new QSpacerItem(15,20);
     QSpacerItem *item4 = new QSpacerItem(19,20);
 
-    QIcon icon;
-    QSize deviceIconSize(16,16);
-    QString deviceBtnIcon = "audio-card";
-    icon = QIcon::fromTheme(deviceBtnIcon);
-    deviceBtn->setIconSize(deviceIconSize);
-    deviceBtn->setIcon(QIcon(icon));
-
     masterVolumeSlider->setOrientation(Qt::Horizontal);
     masterVolumeSlider->setRange(0,100);
     deviceBtn->setFixedSize(16,16);
-    deviceLabel->setFixedSize(154,18);
+    deviceLabel->setFixedSize(240,24);
     masterWidget->setFixedSize(345,31);
     switchBtn->resize(36,36);
     deviceCombox->setFixedSize(300,36);
-    displayVolumeLabel->setFixedSize(32,20);
+    displayVolumeLabel->setFixedSize(55,20);//bjc修复16号字体后最大音量不全
 
-    deviceBtn->move(16,16);
-    deviceLabel->move(36,18);
+    displayWidget->move(0,0);
     deviceCombox->move(2,6);
     switchBtn->move(305,6);
     masterWidget->move(0,59);
@@ -71,15 +75,27 @@ UkmediaMiniMasterVolumeWidget::UkmediaMiniMasterVolumeWidget(QWidget *parent) :
 
     QSize iconSize(32,32);
     muteBtn->setFixedSize(32,32);
-    masterVolumeSlider->setFixedSize(220,22);
+    masterVolumeSlider->setFixedSize(200,22);
     muteBtn->setIconSize(iconSize);
     switchBtn->setIconSize(switchSize);
     deviceBtn->setIconSize(deviceSize);
+    switchBtn->setProperty("useIconHighlightEffect",true);
+    switchBtn->setProperty("iconHighlightEffectMode",true);
+    QIcon icon;
+    QSize deviceIconSize(16,16);
+    QString deviceBtnIcon = "audio-card";
+    icon = QIcon::fromTheme(deviceBtnIcon);
+    deviceBtn->setIconSize(deviceIconSize);
+    deviceBtn->setIcon(QIcon(icon));
+    QPalette palete = deviceBtn->palette();
+    palete.setColor(QPalette::Highlight,Qt::transparent);
+    palete.setBrush(QPalette::Button,QBrush(QColor(1,1,1,0)));
+    deviceBtn->setPalette(palete);
 
     switchBtn->setIcon(QIcon("/usr/share/ukui-media/img/complete-module.svg"));
     this->setFixedSize(345,100);
     setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Popup);
-    setAttribute(Qt::WA_TranslucentBackground);
+    setAttribute(Qt::WA_NoMouseReplay);
     QHBoxLayout *hlayout  = new QHBoxLayout(masterWidget);
 
     hlayout->addItem(item1);
@@ -99,34 +115,6 @@ UkmediaMiniMasterVolumeWidget::UkmediaMiniMasterVolumeWidget(QWidget *parent) :
     connect(switchBtn,SIGNAL(moveMiniSwitchBtnSignale()),this,SLOT(moveMiniSwitchBtnSlot()));
     deviceBtn->setStyleSheet("QPushButton{background:transparent;border:0px;"
                              "padding-left:0px;}");
-    deviceLabel->setStyleSheet("QLabel{font-size:14px;font-family:Noto Sans CJK SC;"
-                               "background-color:transparent;"
-                               "font-weight:400;color:rgba(255,255,255,0.97);"
-                               "line-height:34px;}");
-//    displayVolumeLabel->setStyleSheet("QLabel{font-size:20px;font-family:Noto Sans CJK SC;"
-//                                      "font-weight:400;color:rgba(255,255,255,0.91);"
-//                                      "line-height:24px;opacity:0.91;}");
-    muteBtn->setStyleSheet("QPushButton{background:transparent;border:0px;}");
-    masterVolumeSlider->setStyleSheet("QSlider::groove:horizontal {border: 0px solid #bbb;}"
-                                      "QSlider::sub-page:horizontal {"
-                                      "background: rgb(107,142,235);"
-                                      "border-radius: 2px;"
-                                      "margin-top:9px;"
-                                      "margin-bottom:9px;}"
-                                      "QSlider::add-page:horizontal {"
-                                      "background:  rgba(255,255,255,0.1);"
-                                      "border: 0px solid #777;"
-                                      "border-radius: 2px;"
-                                      "margin-top:9px;"
-                                      "margin-bottom:9px;}"
-                                      "QSlider::handle:horizontal {"
-                                      "width: 20px;"
-                                      "height: 20px;"
-                                      "background: rgb(61,107,229);"
-                                      "border-radius:10px;}");
-//    masterWidget->setStyleSheet("QWidget{background-color:transparent;"
-//                                "border-radius:15px;}");
-
 }
 
 void UkmediaMiniMasterVolumeWidget::paintEvent(QPaintEvent *event)
@@ -135,7 +123,10 @@ void UkmediaMiniMasterVolumeWidget::paintEvent(QPaintEvent *event)
     opt.init(this);
     QPainter p(this);
     double transparence = transparency * 255;
-    p.setBrush(QBrush(QColor(19, 19, 20, transparence)));
+    QColor color = palette().color(QPalette::Base);
+    color.setAlpha(transparence);
+    QBrush brush = QBrush(color);
+    p.setBrush(brush);
     p.setPen(Qt::NoPen);
     QPainterPath path;
     opt.rect.adjust(0,0,0,0);
@@ -171,23 +162,32 @@ void UkmediaMiniMasterVolumeWidget::keyPressEvent(QKeyEvent *event)
     int volumeGain ;
     if (event->key() == Qt::Key_Escape) {
         this->hide();
+        return;
+    }
+    else if (event->key() == Qt::Key_Minus) {
+        volumeGain = -1;
+    }
+    else if (event->key() == Qt::Key_Plus) {
+        volumeGain = 1;
     }
     else if (event->key() == Qt::Key_Up) {
         volumeGain = 1;
-        Q_EMIT keyboard_pressed_signal(volumeGain);
     }
     else if (event->key() == Qt::Key_Down) {
         volumeGain = -1;
-        Q_EMIT keyboard_pressed_signal(volumeGain);
     }
     else if (event->key() == Qt::Key_Left) {
         volumeGain = -1;
-        Q_EMIT keyboard_pressed_signal(volumeGain);
+
     }
     else if (event->key() == Qt::Key_Right) {
         volumeGain = 1;
-        Q_EMIT keyboard_pressed_signal(volumeGain);
     }
+    else {
+        return;
+    }
+
+    Q_EMIT keyboard_pressed_signal(volumeGain);
 }
 
 /*
@@ -209,6 +209,7 @@ bool UkmediaMiniMasterVolumeWidget:: event(QEvent *event)
 void UkmediaMiniMasterVolumeWidget::moveMiniSwitchBtnSlot()
 {
     switchBtn->move(306,7);
+
 }
 
 UkmediaMiniMasterVolumeWidget::~UkmediaMiniMasterVolumeWidget()
